@@ -30,11 +30,6 @@
 #include <gconf/gconf-client.h>
 #include <string.h>
 
-#define GDA_CONFIG_SECTION_DATASOURCES       "/apps/libgda/Datasources"
-#define GDA_CONFIG_SECTION_LAST_CONNECTIONS  "/apps/libgda/LastConnections"
-
-#define GDA_CONFIG_KEY_MAX_LAST_CONNECTIONS  "/apps/libgda/MaxLastConnections"
-
 static GList *activation_property_to_list (Bonobo_ActivationProperty *prop);
 static GdaParameter *activation_property_to_parameter (Bonobo_ActivationProperty *prop);
 static gchar *activation_property_to_string (Bonobo_ActivationProperty *prop);
@@ -482,8 +477,6 @@ gda_config_add_listener (const gchar *path, GdaConfigListenerFunc func, gpointer
 void
 gda_config_remove_listener (guint id)
 {
-	GList *l;
-
 	gconf_client_notify_remove (get_conf_client (), id);
 }
 
@@ -675,26 +668,63 @@ gda_config_free_provider_list (GList *list)
 	for (l = g_list_first (list); l; l = l->next) {
 		GdaProviderInfo *provider_info = (GdaProviderInfo *) l->data;
 
-		if (provider_info != NULL) {
-			g_free (provider_info->id);
-			g_free (provider_info->location);
-			g_free (provider_info->description);
-			g_free (provider_info->username);
-			g_free (provider_info->hostname);
-			g_free (provider_info->domain);
-
-			g_list_foreach (provider_info->repo_ids, (GFunc) g_free, NULL);
-			g_list_free (provider_info->repo_ids);
-			g_list_foreach (provider_info->gda_params, (GFunc) g_free, NULL);
-			g_list_free (provider_info->gda_params);
-
-			g_free (provider_info);
-		}
+		if (provider_info != NULL)
+			gda_config_free_provider_info (provider_info);
 	}
 
 	g_list_free (list);
 }
 
+/**
+ * gda_config_get_provider_by_name
+ */
+GdaProviderInfo *
+gda_config_get_provider_by_name (const gchar *name)
+{
+	GList *prov_list;
+	GList *l;
+
+	prov_list = gda_config_get_provider_list ();
+
+	for (l = prov_list; l != NULL; l = l->next) {
+		GdaProviderInfo *provider_info = (GdaProviderInfo *) l->data;
+
+		if (provider_info && !strcmp (provider_info->id, name)) {
+			l->data = NULL;
+			gda_config_free_provider_list (prov_list);
+
+			return provider_info;
+		}
+	}
+
+	gda_config_free_provider_list (prov_list);
+
+	return NULL;
+}
+
+/**
+ * gda_config_free_provider_info
+ */
+void
+gda_config_free_provider_info (GdaProviderInfo *provider_info)
+{
+	g_return_if_fail (provider_info != NULL);
+
+	g_free (provider_info->id);
+	g_free (provider_info->location);
+	g_free (provider_info->description);
+	g_free (provider_info->username);
+	g_free (provider_info->hostname);
+	g_free (provider_info->domain);
+
+	g_list_foreach (provider_info->repo_ids, (GFunc) g_free, NULL);
+	g_list_free (provider_info->repo_ids);
+	g_list_foreach (provider_info->gda_params, (GFunc) g_free, NULL);
+	g_list_free (provider_info->gda_params);
+
+	g_free (provider_info);
+}
+
 /**
  * gda_config_get_data_source_list
  */
@@ -714,22 +744,22 @@ gda_config_get_data_source_list (void)
 		info->name = g_strdup ((const gchar *) l->data);
 
 		/* get the provider */
-		tmp = g_strdup_printf ("%s/%s/Provider", GDA_CONFIG_SECTION_DATASOURCES, l->data);
+		tmp = g_strdup_printf ("%s/%s/Provider", GDA_CONFIG_SECTION_DATASOURCES, (char *) l->data);
 		info->provider = gda_config_get_string (tmp);
 		g_free (tmp);
 
 		/* get the connection string */
-		tmp = g_strdup_printf ("%s/%s/DSN", GDA_CONFIG_SECTION_DATASOURCES, l->data);
+		tmp = g_strdup_printf ("%s/%s/DSN", GDA_CONFIG_SECTION_DATASOURCES, (char *) l->data);
 		info->cnc_string = gda_config_get_string (tmp);
 		g_free (tmp);
 
 		/* get the description */
-		tmp = g_strdup_printf ("%s/%s/Description", GDA_CONFIG_SECTION_DATASOURCES, l->data);
+		tmp = g_strdup_printf ("%s/%s/Description", GDA_CONFIG_SECTION_DATASOURCES, (char *) l->data);
 		info->description = gda_config_get_string (tmp);
 		g_free (tmp);
 
 		/* get the user name */
-		tmp = g_strdup_printf ("%s/%s/Username", GDA_CONFIG_SECTION_DATASOURCES, l->data);
+		tmp = g_strdup_printf ("%s/%s/Username", GDA_CONFIG_SECTION_DATASOURCES, (char *) l->data);
 		info->username = gda_config_get_string (tmp);
 		g_free (tmp);
 
